/**
 * Copyright (c) 2008-2023, MOVES Institute, Naval Postgraduate School (NPS). All rights reserved.
 * This work is provided under a BSD-style open-source license, see project
 * <a href="https://savage.nps.edu/opendis7-java/license.html" target="_blank">license.html</a> and <a href="https://savage.nps.edu/opendis7-java/license.txt" target="_blank">license.txt</a>
 */
// header autogenerated using string template dis7javalicense.txt



package edu.nps.moves.dis7.pdus;

import java.util.*;
import java.io.*;
import edu.nps.moves.dis7.enumerations.*;

/**
 * 7.6.5.3 Layer 2 emissions data
 * @see <a href="https://ieeexplore.ieee.org/document/6387564" target="_blank">IEEE Std 1278.1-2012, IEEE Standard for Distributed Interactive Simulation - Application Protocols</a> 
 */
public class IFFPduLayer2Data extends AbstractIFFPduLayerData implements Serializable
{
   /** Layer header */
   protected LayerHeader  layerHeader = new LayerHeader(); 

   /** Beam data */
   protected BeamData  beamData = new BeamData(); 

   /** secondaryOpParameter1 is an undescribed parameter... */
   protected byte secondaryOpParameter1;

   /** secondaryOpParameter2 is an undescribed parameter... */
   protected byte secondaryOpParameter2;

   /** numberOfIFFFundamentalParameterDataRecordsParameters is an undescribed parameter... */
   protected short numberOfIFFFundamentalParameterDataRecordsParameters;

   /** Variable length list of fundamental parameters. */
   protected List< IFFFundamentalParameterData > IFFFundamentalParameterDataRecord = new ArrayList<>();
 

/** Constructor creates and configures a new instance object */
 public IFFPduLayer2Data()
 {
 }

  /**
   * Returns size of this serialized (marshalled) object in bytes
   * @see <a href="https://en.wikipedia.org/wiki/Marshalling_(computer_science)" target="_blank">https://en.wikipedia.org/wiki/Marshalling_(computer_science)</a>
   * @return serialized size in bytes
   */
public synchronized int getMarshalledSize()
{
   int marshalSize = 0; 

   marshalSize = super.getMarshalledSize();
   if (layerHeader != null)
       marshalSize += layerHeader.getMarshalledSize();
   if (beamData != null)
       marshalSize += beamData.getMarshalledSize();
   marshalSize += 1;  // secondaryOpParameter1
   marshalSize += 1;  // secondaryOpParameter2
   marshalSize += 2;  // numberOfIFFFundamentalParameterDataRecordsParameters
   if (IFFFundamentalParameterDataRecord != null)
       for (int idx=0; idx < IFFFundamentalParameterDataRecord.size(); idx++)
       {
            IFFFundamentalParameterData listElement = IFFFundamentalParameterDataRecord.get(idx);
            marshalSize += listElement.getMarshalledSize();
       }

   return marshalSize;
}


/** Setter for {@link IFFPduLayer2Data#layerHeader}
  * @param pLayerHeader new value of interest
  * @return same object to permit progressive setters */
public synchronized IFFPduLayer2Data setLayerHeader(LayerHeader pLayerHeader)
{
    layerHeader = pLayerHeader;
    return this;
}
/** Getter for {@link IFFPduLayer2Data#layerHeader}
  * @return value of interest */
public LayerHeader getLayerHeader()
{
    return layerHeader;
}


/** Setter for {@link IFFPduLayer2Data#beamData}
  * @param pBeamData new value of interest
  * @return same object to permit progressive setters */
public synchronized IFFPduLayer2Data setBeamData(BeamData pBeamData)
{
    beamData = pBeamData;
    return this;
}
/** Getter for {@link IFFPduLayer2Data#beamData}
  * @return value of interest */
public BeamData getBeamData()
{
    return beamData;
}


/** Setter for {@link IFFPduLayer2Data#secondaryOpParameter1}
  * @param pSecondaryOpParameter1 new value of interest
  * @return same object to permit progressive setters */
public synchronized IFFPduLayer2Data setSecondaryOpParameter1(byte pSecondaryOpParameter1)
{
    secondaryOpParameter1 = pSecondaryOpParameter1;
    return this;
}
/** Utility setter for {@link IFFPduLayer2Data#secondaryOpParameter1}
  * @param pSecondaryOpParameter1 new value of interest
  * @return same object to permit progressive setters */
public synchronized IFFPduLayer2Data setSecondaryOpParameter1(int pSecondaryOpParameter1){
    secondaryOpParameter1 = (byte) pSecondaryOpParameter1;
    return this;
}
/** Getter for {@link IFFPduLayer2Data#secondaryOpParameter1}
  * @return value of interest */
public byte getSecondaryOpParameter1()
{
    return secondaryOpParameter1; 
}

/** Setter for {@link IFFPduLayer2Data#secondaryOpParameter2}
  * @param pSecondaryOpParameter2 new value of interest
  * @return same object to permit progressive setters */
public synchronized IFFPduLayer2Data setSecondaryOpParameter2(byte pSecondaryOpParameter2)
{
    secondaryOpParameter2 = pSecondaryOpParameter2;
    return this;
}
/** Utility setter for {@link IFFPduLayer2Data#secondaryOpParameter2}
  * @param pSecondaryOpParameter2 new value of interest
  * @return same object to permit progressive setters */
public synchronized IFFPduLayer2Data setSecondaryOpParameter2(int pSecondaryOpParameter2){
    secondaryOpParameter2 = (byte) pSecondaryOpParameter2;
    return this;
}
/** Getter for {@link IFFPduLayer2Data#secondaryOpParameter2}
  * @return value of interest */
public byte getSecondaryOpParameter2()
{
    return secondaryOpParameter2; 
}

/** Utility method to get size of field
 * @return size of field */
public short getNumberOfIFFFundamentalParameterDataRecordsParameters()
{
    return (short)IFFFundamentalParameterDataRecord.size(); 
}

/** Note that setting this value will not change the marshalled value. The list whose length this describes is used for that purpose.
 * The getnumberOfIFFFundamentalParameterDataRecordsParameters method will also be based on the actual list length rather than this value. 
 * The method is simply here for java bean completeness.
 * @param pNumberOfIFFFundamentalParameterDataRecordsParameters passed parameter
 * @return this object
 */
public synchronized IFFPduLayer2Data setNumberOfIFFFundamentalParameterDataRecordsParameters(short pNumberOfIFFFundamentalParameterDataRecordsParameters)
{
    numberOfIFFFundamentalParameterDataRecordsParameters = pNumberOfIFFFundamentalParameterDataRecordsParameters;
    return this;
}

/** Setter for {@link IFFPduLayer2Data#IFFFundamentalParameterDataRecord}
  * @param pIFFFundamentalParameterDataRecord new value of interest
  * @return same object to permit progressive setters */
public synchronized IFFPduLayer2Data setIFFFundamentalParameterDataRecord(List<IFFFundamentalParameterData> pIFFFundamentalParameterDataRecord)
{
    IFFFundamentalParameterDataRecord = pIFFFundamentalParameterDataRecord;
    return this;
}
/** Getter for {@link IFFPduLayer2Data#IFFFundamentalParameterDataRecord}
  * @return value of interest */
public List<IFFFundamentalParameterData> getIFFFundamentalParameterDataRecord()
{
    return IFFFundamentalParameterDataRecord; 
}

/**
 * Serializes an object to a DataOutputStream.
 * @throws java.lang.Exception if something goes wrong
 * @see java.io.DataOutputStream
 * @param dos the OutputStream
 */
public synchronized void marshal(DataOutputStream dos) throws Exception
{
    super.marshal(dos);
    try 
    {
       layerHeader.marshal(dos);
       beamData.marshal(dos);
       dos.writeByte(secondaryOpParameter1);
       dos.writeByte(secondaryOpParameter2);
       dos.writeShort(IFFFundamentalParameterDataRecord.size());

       for (int idx = 0; idx < IFFFundamentalParameterDataRecord.size(); idx++)
       {
            IFFFundamentalParameterData aIFFFundamentalParameterData = IFFFundamentalParameterDataRecord.get(idx);
            aIFFFundamentalParameterData.marshal(dos);
       }

    }
    catch(Exception e)
    {
      System.err.println(e);
    }
}

/**
 * Deserializes an object from a DataInputStream.
 * @throws java.lang.Exception if something goes wrong
 * @see java.io.DataInputStream
 * @see <a href="https://en.wikipedia.org/wiki/Marshalling_(computer_science)" target="_blank">https://en.wikipedia.org/wiki/Marshalling_(computer_science)</a>
 * @param dis the InputStream
 * @return marshalled serialized size in bytes
 */
public synchronized int unmarshal(DataInputStream dis) throws Exception
{
    int uPosition = 0;
    uPosition += super.unmarshal(dis);

    try 
    {
        uPosition += layerHeader.unmarshal(dis);
        uPosition += beamData.unmarshal(dis);
        secondaryOpParameter1 = (byte)dis.readUnsignedByte();
        uPosition += 1;
        secondaryOpParameter2 = (byte)dis.readUnsignedByte();
        uPosition += 1;
        numberOfIFFFundamentalParameterDataRecordsParameters = (short)dis.readUnsignedShort();
        uPosition += 2;
        for (int idx = 0; idx < numberOfIFFFundamentalParameterDataRecordsParameters; idx++)
        {
            IFFFundamentalParameterData anX = new IFFFundamentalParameterData();
            uPosition += anX.unmarshal(dis);
            IFFFundamentalParameterDataRecord.add(anX);
        }

    }
    catch(Exception e)
    { 
      System.err.println(e); 
    }
    return getMarshalledSize();
}

/**
 * Packs an object into the ByteBuffer.
 * @throws java.nio.BufferOverflowException if byteBuffer is too small
 * @throws java.nio.ReadOnlyBufferException if byteBuffer is read only
 * @see java.nio.ByteBuffer
 * @param byteBuffer The ByteBuffer at the position to begin writing
 * @throws Exception ByteBuffer-generated exception
 */
public synchronized void marshal(java.nio.ByteBuffer byteBuffer) throws Exception
{
   super.marshal(byteBuffer);
   layerHeader.marshal(byteBuffer);
   beamData.marshal(byteBuffer);
   byteBuffer.put( (byte)secondaryOpParameter1);
   byteBuffer.put( (byte)secondaryOpParameter2);
   byteBuffer.putShort( (short)IFFFundamentalParameterDataRecord.size());

   for (int idx = 0; idx < IFFFundamentalParameterDataRecord.size(); idx++)
   {
        IFFFundamentalParameterData aIFFFundamentalParameterData = IFFFundamentalParameterDataRecord.get(idx);
        aIFFFundamentalParameterData.marshal(byteBuffer);
   }

}

/**
 * Unpacks a Pdu from the underlying data.
 * @throws java.nio.BufferUnderflowException if byteBuffer is too small
 * @see java.nio.ByteBuffer
 * @see <a href="https://en.wikipedia.org/wiki/Marshalling_(computer_science)" target="_blank">https://en.wikipedia.org/wiki/Marshalling_(computer_science)</a>
 * @param byteBuffer The ByteBuffer at the position to begin reading
 * @return marshalled serialized size in bytes
 * @throws Exception ByteBuffer-generated exception
 */
public synchronized int unmarshal(java.nio.ByteBuffer byteBuffer) throws Exception
{
    super.unmarshal(byteBuffer);

    try
    {
        // attribute layerHeader marked as not serialized
        layerHeader.unmarshal(byteBuffer);
        // attribute beamData marked as not serialized
        beamData.unmarshal(byteBuffer);
        // attribute secondaryOpParameter1 marked as not serialized
        secondaryOpParameter1 = (byte)(byteBuffer.get() & 0xFF);
        // attribute secondaryOpParameter2 marked as not serialized
        secondaryOpParameter2 = (byte)(byteBuffer.get() & 0xFF);
        // attribute numberOfIFFFundamentalParameterDataRecordsParameters marked as not serialized
        numberOfIFFFundamentalParameterDataRecordsParameters = (short)(byteBuffer.getShort() & 0xFFFF);
        // attribute IFFFundamentalParameterDataRecord marked as not serialized
        for (int idx = 0; idx < numberOfIFFFundamentalParameterDataRecordsParameters; idx++)
        {
        IFFFundamentalParameterData anX = new IFFFundamentalParameterData();
        anX.unmarshal(byteBuffer);
        IFFFundamentalParameterDataRecord.add(anX);
        }

    }
    catch (java.nio.BufferUnderflowException bue)
    {
        System.err.println("*** buffer underflow error while unmarshalling " + this.getClass().getName());
    }
    return getMarshalledSize();
}

 /*
  * Override of default equals method.  Calls equalsImpl() for content comparison.
  */
@Override
 public synchronized boolean equals(Object obj)
 {
    if(this == obj)
      return true;

    if(obj == null)
       return false;

    if(!getClass().isAssignableFrom(obj.getClass())) //if(getClass() != obj.getClass())
        return false;

    return equalsImpl(obj);
 }

@Override
 public synchronized boolean equalsImpl(Object obj)
 {
     final IFFPduLayer2Data rhs = (IFFPduLayer2Data)obj;

     if( ! Objects.equals(layerHeader, rhs.layerHeader) ) return false;
     if( ! Objects.equals(beamData, rhs.beamData) ) return false;
     if( ! (secondaryOpParameter1 == rhs.secondaryOpParameter1)) return false;
     if( ! (secondaryOpParameter2 == rhs.secondaryOpParameter2)) return false;
     if( ! (numberOfIFFFundamentalParameterDataRecordsParameters == rhs.numberOfIFFFundamentalParameterDataRecordsParameters)) return false;
     if( ! Objects.equals(IFFFundamentalParameterDataRecord, rhs.IFFFundamentalParameterDataRecord) ) return false;
    return super.equalsImpl(rhs);
 }

 @Override
 public synchronized String toString()
 {
    StringBuilder sb  = new StringBuilder();
    StringBuilder sb2 = new StringBuilder();
    sb.append(getClass().getSimpleName());
    sb.append(" layerHeader:").append(layerHeader); // writeOneToString
    sb.append(" beamData:").append(beamData); // writeOneToString
    sb.append(" secondaryOpParameter1:").append(secondaryOpParameter1); // writeOneToString
    sb.append(" secondaryOpParameter2:").append(secondaryOpParameter2); // writeOneToString
    sb.append(" numberOfIFFFundamentalParameterDataRecordsParameters:").append(numberOfIFFFundamentalParameterDataRecordsParameters); // writeOneToString
    sb.append(" IFFFundamentalParameterDataRecord: ");
    IFFFundamentalParameterDataRecord.forEach(r->{ sb2.append(" ").append(r);}); // writeList
    sb.append(sb2.toString().trim());
    // https://stackoverflow.com/questions/2242471/clearing-a-string-buffer-builder-after-loop
    sb2.setLength(0); // reset

   return sb.toString();
 }

 @Override
 public int hashCode()
 {
	 return Objects.hash(this.layerHeader,
	                     this.beamData,
	                     this.secondaryOpParameter1,
	                     this.secondaryOpParameter2,
	                     this.numberOfIFFFundamentalParameterDataRecordsParameters,
	                     this.IFFFundamentalParameterDataRecord);
 }
} // end of IFFPduLayer2Data
