/**
 * Copyright (c) 2008-2023, MOVES Institute, Naval Postgraduate School (NPS). All rights reserved.
 * This work is provided under a BSD-style open-source license, see project
 * <a href="https://savage.nps.edu/opendis7-java/license.html" target="_blank">license.html</a> and <a href="https://savage.nps.edu/opendis7-java/license.txt" target="_blank">license.txt</a>
 */
// header autogenerated using string template dis7javalicense.txt



package edu.nps.moves.dis7.pdus;

import java.util.*;
import java.io.*;
import edu.nps.moves.dis7.enumerations.*;

/**
 * 6.2.48.3
 * @see <a href="https://ieeexplore.ieee.org/document/6387564" target="_blank">IEEE Std 1278.1-2012, IEEE Standard for Distributed Interactive Simulation - Application Protocols</a> 
 */
public class IOEffectRecord extends IORecord implements Serializable
{
   /**  uid 66 Variable Record Type values are defined by VariableRecordType enumerations */
   protected VariableRecordType recordType = VariableRecordType.IO_EFFECT;

   /** recordLength is an undescribed parameter... */
   protected short recordLength;

   /**  uid 290 */
   protected IOEffectsRecordIOStatus ioStatus = IOEffectsRecordIOStatus.values()[0];

   /**  uid 291 */
   protected IOEffectsRecordIOLinkType ioLinkType = IOEffectsRecordIOLinkType.values()[0];

   /**  uid 292 */
   protected IOEffectsRecordIOEffect ioEffect = IOEffectsRecordIOEffect.values()[0];

   /** ioEffectDutyCycle is an undescribed parameter... */
   protected byte ioEffectDutyCycle;

   /** ioEffectDuration is an undescribed parameter... */
   protected short ioEffectDuration;

   /**  uid 293 */
   protected IOEffectsRecordIOProcess ioProcess = IOEffectsRecordIOProcess.values()[0];

   /** zero-filled array of padding bits for byte alignment and consistent sizing of PDU data */
   protected short padding;


/** Constructor creates and configures a new instance object */
 public IOEffectRecord()
 {
 }

  /**
   * Returns size of this serialized (marshalled) object in bytes
   * @see <a href="https://en.wikipedia.org/wiki/Marshalling_(computer_science)" target="_blank">https://en.wikipedia.org/wiki/Marshalling_(computer_science)</a>
   * @return serialized size in bytes
   */
public synchronized int getMarshalledSize()
{
   int marshalSize = 0; 

   marshalSize = super.getMarshalledSize();
   if (recordType != null)
       marshalSize += recordType.getMarshalledSize();
   marshalSize += 2;  // recordLength
   if (ioStatus != null)
       marshalSize += ioStatus.getMarshalledSize();
   if (ioLinkType != null)
       marshalSize += ioLinkType.getMarshalledSize();
   if (ioEffect != null)
       marshalSize += ioEffect.getMarshalledSize();
   marshalSize += 1;  // ioEffectDutyCycle
   marshalSize += 2;  // ioEffectDuration
   if (ioProcess != null)
       marshalSize += ioProcess.getMarshalledSize();
   marshalSize += 2;  // padding

   return marshalSize;
}


/** Setter for {@link IOEffectRecord#recordType}
  * @param pRecordType new value of interest
  * @return same object to permit progressive setters */
public synchronized IOEffectRecord setRecordType(VariableRecordType pRecordType)
{
    recordType = pRecordType;
    return this;
}
/** Getter for {@link IOEffectRecord#recordType}
  * @return value of interest */
public VariableRecordType getRecordType()
{
    return recordType; 
}

/** Setter for {@link IOEffectRecord#recordLength}
  * @param pRecordLength new value of interest
  * @return same object to permit progressive setters */
public synchronized IOEffectRecord setRecordLength(short pRecordLength)
{
    recordLength = pRecordLength;
    return this;
}
/** Utility setter for {@link IOEffectRecord#recordLength}
  * @param pRecordLength new value of interest
  * @return same object to permit progressive setters */
public synchronized IOEffectRecord setRecordLength(int pRecordLength){
    recordLength = (short) pRecordLength;
    return this;
}
/** Getter for {@link IOEffectRecord#recordLength}
  * @return value of interest */
public short getRecordLength()
{
    return recordLength; 
}

/** Setter for {@link IOEffectRecord#ioStatus}
  * @param pIoStatus new value of interest
  * @return same object to permit progressive setters */
public synchronized IOEffectRecord setIoStatus(IOEffectsRecordIOStatus pIoStatus)
{
    ioStatus = pIoStatus;
    return this;
}
/** Getter for {@link IOEffectRecord#ioStatus}
  * @return value of interest */
public IOEffectsRecordIOStatus getIoStatus()
{
    return ioStatus; 
}

/** Setter for {@link IOEffectRecord#ioLinkType}
  * @param pIoLinkType new value of interest
  * @return same object to permit progressive setters */
public synchronized IOEffectRecord setIoLinkType(IOEffectsRecordIOLinkType pIoLinkType)
{
    ioLinkType = pIoLinkType;
    return this;
}
/** Getter for {@link IOEffectRecord#ioLinkType}
  * @return value of interest */
public IOEffectsRecordIOLinkType getIoLinkType()
{
    return ioLinkType; 
}

/** Setter for {@link IOEffectRecord#ioEffect}
  * @param pIoEffect new value of interest
  * @return same object to permit progressive setters */
public synchronized IOEffectRecord setIoEffect(IOEffectsRecordIOEffect pIoEffect)
{
    ioEffect = pIoEffect;
    return this;
}
/** Getter for {@link IOEffectRecord#ioEffect}
  * @return value of interest */
public IOEffectsRecordIOEffect getIoEffect()
{
    return ioEffect; 
}

/** Setter for {@link IOEffectRecord#ioEffectDutyCycle}
  * @param pIoEffectDutyCycle new value of interest
  * @return same object to permit progressive setters */
public synchronized IOEffectRecord setIoEffectDutyCycle(byte pIoEffectDutyCycle)
{
    ioEffectDutyCycle = pIoEffectDutyCycle;
    return this;
}
/** Utility setter for {@link IOEffectRecord#ioEffectDutyCycle}
  * @param pIoEffectDutyCycle new value of interest
  * @return same object to permit progressive setters */
public synchronized IOEffectRecord setIoEffectDutyCycle(int pIoEffectDutyCycle){
    ioEffectDutyCycle = (byte) pIoEffectDutyCycle;
    return this;
}
/** Getter for {@link IOEffectRecord#ioEffectDutyCycle}
  * @return value of interest */
public byte getIoEffectDutyCycle()
{
    return ioEffectDutyCycle; 
}

/** Setter for {@link IOEffectRecord#ioEffectDuration}
  * @param pIoEffectDuration new value of interest
  * @return same object to permit progressive setters */
public synchronized IOEffectRecord setIoEffectDuration(short pIoEffectDuration)
{
    ioEffectDuration = pIoEffectDuration;
    return this;
}
/** Utility setter for {@link IOEffectRecord#ioEffectDuration}
  * @param pIoEffectDuration new value of interest
  * @return same object to permit progressive setters */
public synchronized IOEffectRecord setIoEffectDuration(int pIoEffectDuration){
    ioEffectDuration = (short) pIoEffectDuration;
    return this;
}
/** Getter for {@link IOEffectRecord#ioEffectDuration}
  * @return value of interest */
public short getIoEffectDuration()
{
    return ioEffectDuration; 
}

/** Setter for {@link IOEffectRecord#ioProcess}
  * @param pIoProcess new value of interest
  * @return same object to permit progressive setters */
public synchronized IOEffectRecord setIoProcess(IOEffectsRecordIOProcess pIoProcess)
{
    ioProcess = pIoProcess;
    return this;
}
/** Getter for {@link IOEffectRecord#ioProcess}
  * @return value of interest */
public IOEffectsRecordIOProcess getIoProcess()
{
    return ioProcess; 
}

/** Setter for {@link IOEffectRecord#padding}
  * @param pPadding new value of interest
  * @return same object to permit progressive setters */
public synchronized IOEffectRecord setPadding(short pPadding)
{
    padding = pPadding;
    return this;
}
/** Utility setter for {@link IOEffectRecord#padding}
  * @param pPadding new value of interest
  * @return same object to permit progressive setters */
public synchronized IOEffectRecord setPadding(int pPadding){
    padding = (short) pPadding;
    return this;
}
/** Getter for {@link IOEffectRecord#padding}
  * @return value of interest */
public short getPadding()
{
    return padding; 
}

/**
 * Serializes an object to a DataOutputStream.
 * @throws java.lang.Exception if something goes wrong
 * @see java.io.DataOutputStream
 * @param dos the OutputStream
 */
public synchronized void marshal(DataOutputStream dos) throws Exception
{
    super.marshal(dos);
    try 
    {
       recordType.marshal(dos);
       dos.writeShort(recordLength);
       ioStatus.marshal(dos);
       ioLinkType.marshal(dos);
       ioEffect.marshal(dos);
       dos.writeByte(ioEffectDutyCycle);
       dos.writeShort(ioEffectDuration);
       ioProcess.marshal(dos);
       dos.writeShort(padding);
    }
    catch(Exception e)
    {
      System.err.println(e);
    }
}

/**
 * Deserializes an object from a DataInputStream.
 * @throws java.lang.Exception if something goes wrong
 * @see java.io.DataInputStream
 * @see <a href="https://en.wikipedia.org/wiki/Marshalling_(computer_science)" target="_blank">https://en.wikipedia.org/wiki/Marshalling_(computer_science)</a>
 * @param dis the InputStream
 * @return marshalled serialized size in bytes
 */
public synchronized int unmarshal(DataInputStream dis) throws Exception
{
    int uPosition = 0;
    uPosition += super.unmarshal(dis);

    try 
    {
        recordType = VariableRecordType.unmarshalEnum(dis);
        uPosition += recordType.getMarshalledSize();
        recordLength = (short)dis.readUnsignedShort();
        uPosition += 2;
        ioStatus = IOEffectsRecordIOStatus.unmarshalEnum(dis);
        uPosition += ioStatus.getMarshalledSize();
        ioLinkType = IOEffectsRecordIOLinkType.unmarshalEnum(dis);
        uPosition += ioLinkType.getMarshalledSize();
        ioEffect = IOEffectsRecordIOEffect.unmarshalEnum(dis);
        uPosition += ioEffect.getMarshalledSize();
        ioEffectDutyCycle = (byte)dis.readUnsignedByte();
        uPosition += 1;
        ioEffectDuration = (short)dis.readUnsignedShort();
        uPosition += 2;
        ioProcess = IOEffectsRecordIOProcess.unmarshalEnum(dis);
        uPosition += ioProcess.getMarshalledSize();
        padding = (short)dis.readUnsignedShort();
        uPosition += 2;
    }
    catch(Exception e)
    { 
      System.err.println(e); 
    }
    return getMarshalledSize();
}

/**
 * Packs an object into the ByteBuffer.
 * @throws java.nio.BufferOverflowException if byteBuffer is too small
 * @throws java.nio.ReadOnlyBufferException if byteBuffer is read only
 * @see java.nio.ByteBuffer
 * @param byteBuffer The ByteBuffer at the position to begin writing
 * @throws Exception ByteBuffer-generated exception
 */
public synchronized void marshal(java.nio.ByteBuffer byteBuffer) throws Exception
{
   super.marshal(byteBuffer);
   recordType.marshal(byteBuffer);
   byteBuffer.putShort( (short)recordLength);
   ioStatus.marshal(byteBuffer);
   ioLinkType.marshal(byteBuffer);
   ioEffect.marshal(byteBuffer);
   byteBuffer.put( (byte)ioEffectDutyCycle);
   byteBuffer.putShort( (short)ioEffectDuration);
   ioProcess.marshal(byteBuffer);
   byteBuffer.putShort( (short)padding);
}

/**
 * Unpacks a Pdu from the underlying data.
 * @throws java.nio.BufferUnderflowException if byteBuffer is too small
 * @see java.nio.ByteBuffer
 * @see <a href="https://en.wikipedia.org/wiki/Marshalling_(computer_science)" target="_blank">https://en.wikipedia.org/wiki/Marshalling_(computer_science)</a>
 * @param byteBuffer The ByteBuffer at the position to begin reading
 * @return marshalled serialized size in bytes
 * @throws Exception ByteBuffer-generated exception
 */
public synchronized int unmarshal(java.nio.ByteBuffer byteBuffer) throws Exception
{
    super.unmarshal(byteBuffer);

    try
    {
        // attribute recordType marked as not serialized
        recordType = VariableRecordType.unmarshalEnum(byteBuffer);
        // attribute recordLength marked as not serialized
        recordLength = (short)(byteBuffer.getShort() & 0xFFFF);
        // attribute ioStatus marked as not serialized
        ioStatus = IOEffectsRecordIOStatus.unmarshalEnum(byteBuffer);
        // attribute ioLinkType marked as not serialized
        ioLinkType = IOEffectsRecordIOLinkType.unmarshalEnum(byteBuffer);
        // attribute ioEffect marked as not serialized
        ioEffect = IOEffectsRecordIOEffect.unmarshalEnum(byteBuffer);
        // attribute ioEffectDutyCycle marked as not serialized
        ioEffectDutyCycle = (byte)(byteBuffer.get() & 0xFF);
        // attribute ioEffectDuration marked as not serialized
        ioEffectDuration = (short)(byteBuffer.getShort() & 0xFFFF);
        // attribute ioProcess marked as not serialized
        ioProcess = IOEffectsRecordIOProcess.unmarshalEnum(byteBuffer);
        // attribute padding marked as not serialized
        padding = (short)(byteBuffer.getShort() & 0xFFFF);
    }
    catch (java.nio.BufferUnderflowException bue)
    {
        System.err.println("*** buffer underflow error while unmarshalling " + this.getClass().getName());
    }
    return getMarshalledSize();
}

 /*
  * Override of default equals method.  Calls equalsImpl() for content comparison.
  */
@Override
 public synchronized boolean equals(Object obj)
 {
    if(this == obj)
      return true;

    if(obj == null)
       return false;

    if(!getClass().isAssignableFrom(obj.getClass())) //if(getClass() != obj.getClass())
        return false;

    return equalsImpl(obj);
 }

@Override
 public synchronized boolean equalsImpl(Object obj)
 {
     final IOEffectRecord rhs = (IOEffectRecord)obj;

     if( ! (recordType == rhs.recordType)) return false;
     if( ! (recordLength == rhs.recordLength)) return false;
     if( ! (ioStatus == rhs.ioStatus)) return false;
     if( ! (ioLinkType == rhs.ioLinkType)) return false;
     if( ! (ioEffect == rhs.ioEffect)) return false;
     if( ! (ioEffectDutyCycle == rhs.ioEffectDutyCycle)) return false;
     if( ! (ioEffectDuration == rhs.ioEffectDuration)) return false;
     if( ! (ioProcess == rhs.ioProcess)) return false;
     if( ! (padding == rhs.padding)) return false;
    return super.equalsImpl(rhs);
 }

 @Override
 public synchronized String toString()
 {
    StringBuilder sb  = new StringBuilder();
    StringBuilder sb2 = new StringBuilder();
    sb.append(getClass().getSimpleName());
    sb.append(" recordType:").append(recordType); // writeOneToString
    sb.append(" recordLength:").append(recordLength); // writeOneToString
    sb.append(" ioStatus:").append(ioStatus); // writeOneToString
    sb.append(" ioLinkType:").append(ioLinkType); // writeOneToString
    sb.append(" ioEffect:").append(ioEffect); // writeOneToString
    sb.append(" ioEffectDutyCycle:").append(ioEffectDutyCycle); // writeOneToString
    sb.append(" ioEffectDuration:").append(ioEffectDuration); // writeOneToString
    sb.append(" ioProcess:").append(ioProcess); // writeOneToString
    sb.append(" padding:").append(padding); // writeOneToString

   return sb.toString();
 }

 @Override
 public int hashCode()
 {
	 return Objects.hash(this.recordType,
	                     this.recordLength,
	                     this.ioStatus,
	                     this.ioLinkType,
	                     this.ioEffect,
	                     this.ioEffectDutyCycle,
	                     this.ioEffectDuration,
	                     this.ioProcess,
	                     this.padding);
 }
} // end of IOEffectRecord
